from pathlib import Path

from base.url.url_view_factory import UrlViewFactory
from blackfennec.extension.extension import Extension
from blackfennec.extension.extension_api import ExtensionApi
from blackfennec.interpretation.specification import Specification
from base.date_time.date_time import DateTime

from base.date_time.date_time_view_factory import DateTimeViewFactory
from base.file.file_view_factory import FileViewFactory
from base.image.image_view_factory import ImageViewFactory

BASE_NAME = Path(__file__).parent.as_posix()


class BaseExtension(Extension):
    def __init__(self, api: ExtensionApi):
        super().__init__('base', api, dependencies={'core'})
        self.types = []

        self.view_factories = [
            DateTimeViewFactory(),
            FileViewFactory(self._api.document_registry),
            ImageViewFactory(self._api.document_registry),
            UrlViewFactory(self._api.ui_service)
        ]

    def register_types(self):
        self.types = [
            DateTime.TYPE,
            self._api.type_loader.load(BASE_NAME + '/file/file.json'),
            self._api.type_loader.load(BASE_NAME + '/image/image.json'),
            self._api.type_loader.load(BASE_NAME + '/url/url.json')
        ]

        self._api.type_registry.register_type(DateTime.TYPE)

    def deregister_types(self):
        for t in self.types:
            self._api.type_registry.deregister_type(t)

    def register_view_factories(self):
        for specification in [Specification(), Specification(True)]:
            for type, view_factory in zip(self.types, self.view_factories):
                if not view_factory.satisfies(specification):
                    continue
                self._api.view_factory_registry.register_type_view_factory(
                    type, specification, view_factory)

    def deregister_view_factories(self):
        for specification in [Specification(), Specification(True)]:
            for type, view_factory in zip(self.types, self.view_factories):
                if not view_factory.satisfies(specification):
                    continue
                self._api.view_factory_registry.deregister_type_view_factory(
                    type, specification)
