import os
from pathlib import Path
from base.url.url_view_model import UrlViewModel
from blackfennec.actions.context import Context
from blackfennec.presentation_system.ui_service.message import Message
from blackfennec.presentation_system.ui_service.ui_service import UiService
from blackfennec.presentation_system.type_view import TypeView
from blackfennec.util.change_notification import ChangeNotification

from gi.repository import Gtk


BASE_DIR = Path(__file__).resolve().parent
UI_TEMPLATE = str(BASE_DIR.joinpath('url_preview.ui'))


@Gtk.Template(filename=UI_TEMPLATE)
class UrlPreview(Gtk.Box, TypeView):
    __gtype_name__ = 'UrlPreview'
    _value = Gtk.Template.Child()

    def __init__(self, view_model: UrlViewModel, ui_service: UiService):
        super().__init__()
        self._view_model = view_model
        self._ui_service = ui_service
        self._view_model.bind(changed=self._update_value)
        self._buffer_listener_paused = False

        buffer = self._value.get_buffer()
        buffer.set_text(self._view_model.url)
        buffer.set_enable_undo(False)
        buffer.connect('changed', self._on_buffer_changed)
        self.connect('notify::active', self._on_activate)

    @property
    def text(self):
        buffer = self._value.get_buffer()
        start, end = buffer.get_bounds()
        return buffer.get_text(start, end, False)

    @text.setter
    def text(self, text):
        buffer = self._value.get_buffer()
        start, end = buffer.get_bounds()
        if buffer.get_text(start, end, False) == text:
            return
        self._buffer_listener_paused = True
        buffer.set_text(text, len(text))

    def _on_activate(self, unused_sender):
        self._value.activate()

    def _on_buffer_changed(self, buffer):
        # This is a workaround for a bug in Gtk.TextView
        #   when we set the text in the buffer, the buffer-changed signal is
        #   emitted, twice. The first time with an empty url.

        if self._buffer_listener_paused:
            self._buffer_listener_paused = False
            return

        self._view_model.url = self.text

    def _update_value(self, unused_sender, notification: ChangeNotification):
        self.text = notification.new_value

    @Gtk.Template.Callback()
    def _on_open_clicked(self, unused_sender):
        os.system(f"xdg-open {self.text}")
        context = Context(self)
        message = Message('Url opened')
        self._ui_service.show_message(context, message)