import pytest

from blackfennec_doubles.document_system.double_document_registry import DocumentRegistryMock
from blackfennec_doubles.interpretation.double_interpretation import InterpretationMock
from blackfennec_doubles.interpretation.double_specification import SpecificationMock
from blackfennec_doubles.structure.double_string import StringMock
from base.url.url_preview import UrlPreview
from base.url.url_view_factory import UrlViewFactory


@pytest.fixture
def factory():
    return UrlViewFactory(
        DocumentRegistryMock())


def test_can_construct(factory):
    assert factory


def test_can_create_url_preview(factory):
    view = factory.create(
        InterpretationMock(
            structure=StringMock("https://blackfennec.org"),
            specification=SpecificationMock(request_preview=True)))
    assert isinstance(view, UrlPreview)


def test_satisfies_default(factory):
    satisfies = factory.satisfies(SpecificationMock())
    assert not satisfies


def test_does_not_satisfy_preview(factory):
    satisfies = factory.satisfies(SpecificationMock(request_preview=True))
    assert satisfies
